@@ -1,7 +1,8 @@
 /*
- *  Copyright James Morse Y2K+1   please read COPYING
+ *  Copyright James Morse Y2K +1, +2   
+ *  please read COPYING
  *
- *  Questions and comments may be sent to: xbeastx@writeme.com 
+ *  Questions and comments may be sent to: xbeastx@yahoo.com 
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -37,6 +38,9 @@
 #include "look.h"
 #include "error.h"
 
+/* debugging messages to stderr */
+#define DB_M
+
 int main(int argc, char *argv[])
 {
 	int tmpr = 0, tmpc = 0;
@@ -48,26 +52,108 @@ int main(int argc, char *argv[])
 	int dm = 0;
 	int pf = 0;
 	char *sbis = "";
+	char *tmp = NULL;
+		
+	/* get phyical screen dims ... if we can find it? */
+	#ifdef DB_M
+		fprintf(stderr, "trying to get screen size ...\n");
+	#endif
 	
-	/* default world size to phyical screen */
-	world_row = RROW - 5;
-	world_col = RCOL;
+	// getenv("LINES")?
+	//tmp = ???;
+
+	if (tmp == NULL)
+	{
+		#ifdef DB_M
+			fprintf(stderr, "... defaulting to 24 Rows!\n");
+		#endif
+		rrow = 24;
+	}
+	else
+	{
+		rrow = atoi(tmp);
+		#ifdef DB_M
+			fprintf(stderr, "%i Rows x", rrow);
+		#endif
+	}
+
+	// getenv("COLUMNS")?
+	//tmp = ???;
+
+	if (tmp == NULL)
+	{
+		#ifdef DB_M
+			fprintf(stderr, "... defaulting to 80 Cols!\n");
+		#endif
+		rcol = 80;
+	}
+	else
+	{
+		rcol = atoi(tmp);
+		#ifdef DB_M
+			fprintf(stderr, " %i Cols\n", rcol);
+		#endif
+	}
+	
+	/* set default world size = screen size*/
+	world_row = rrow - 5;
+	world_col = rcol;
 		
 	/* parse cammand line */
 	if (argc > 1)
 	{
 		for (temp = 1; temp < argc; temp++)
 		{
-			/* set world size */
+			/* set screen size */
 			if (strcmp (argv[temp], "-s") == 0)
 			{
+				int fw = 1;
+				/* do we need to adjust worl size? */
+				if ((world_row != (rrow - 5)) || (world_col != rcol))
+					fw = 0;
+				#ifdef DB_M
+					fprintf(stderr, "over rideing default sceen size ...\n");
+				#endif
+				rrow = atoi (argv[++temp]);
+				rcol = atoi (argv[++temp]);
+				if (!rrow || !rcol)
+				{
+					printf ("try -s [rows cols]\n");
+					exit (CMDL_4);
+				}
+				/* reset world size */
+				#ifdef DB_M
+					fprintf(stderr, "now %i Rows x %i Cols\n", rrow, rcol);
+				#endif
+				if (fw == 1)
+				{
+					#ifdef DB_M
+						fprintf(stderr, "making default world the same ...\n");
+					#endif
+					world_row = rrow - 5;
+					world_col = rcol;
+				}
+				#ifdef DB_M
+					fprintf(stderr, "\n");
+				#endif
+			}
+
+			/* set world size */
+			else if (strcmp (argv[temp], "-w") == 0)
+			{
+				#ifdef DB_M
+					fprintf(stderr, "over rideing default world size ...\n");
+				#endif
 				world_row = atoi (argv[++temp]);
 				world_col = atoi (argv[++temp]);
 				if (!world_row || !world_col)
 				{
-					fprintf (stderr, "try -s [rows cols]\n");
+					printf ("try -w [rows cols]\n");
 					exit (CMDL_1);
 				}
+				#ifdef DB_M
+					fprintf(stderr, "now %i Rows x %i Cols\n\n", world_row, world_col);
+				#endif
 			}
 
 			/* set roughness */
@@ -76,9 +162,12 @@ int main(int argc, char *argv[])
 				roughness = atoi (argv[++temp]);
 				if ((roughness < 1) || (roughness > 1000))
 				{
-					fprintf (stderr, "try -r [1-1000]\n");
+					printf ("try -r [1-1000]\n");
 					exit (CMDL_2);
 				}
+				#ifdef DB_M
+					fprintf(stderr, "setting roughness to %i\n", roughness);
+				#endif
 			}
 
 			/* set grid size */
@@ -87,9 +176,12 @@ int main(int argc, char *argv[])
 				grid_size = atoi (argv[++temp]);
 				if ((grid_size < 2) || (grid_size > 8))
 				{
-					fprintf (stderr, "try -g [2-8]\n");
+					printf ("try -g [2-8]\n");
 					exit (CMDL_3);
 				}
+				#ifdef DB_M
+					fprintf(stderr, "setting grid size to %i\n", grid_size);
+				#endif
 			}
 
 			/* display licnse */
@@ -99,10 +191,19 @@ int main(int argc, char *argv[])
 				exit(GNU_L);
 			}
 
-			/* bad user ... */
+			/* display help */
+			else if (strcmp (argv[temp], "-h") == 0)
+			{
+				printf ("usage is ...\n");
+				printf ("bug6 [[ -s # # ][ -w # # ][ -r # ][ -g # ][ -l ][ -h ]]\n");
+				exit(CMDL_H);
+			}
+
+			/* Bad user ... NO BISCUT!!! */
 			else 
 			{
-				fprintf (stderr, "bad args\n");
+				printf ("bad args try ...\n");
+				printf ("bug6 [[ -s # # ][ -w # # ][ -r # ][ -g # ][ -l ][ -h ]]\n");
 				exit (CMDL_U);
 			}
 		}
@@ -114,7 +215,7 @@ int main(int argc, char *argv[])
 	/* make the world */
 	if ((world = (char *)malloc(world_row * world_col)) == NULL)
 	{
-		printf("bad malloc ... no world!!!\n");
+		fprintf(stderr, "bad malloc ... no world!!!\n");
 		exit(BM_B6);
 	}
 	printf("So we made a world and it was good ...\n");
@@ -137,7 +238,7 @@ int main(int argc, char *argv[])
 	printf("And bugs appeared ...\n");
 	printf("\n");
 	printf("They ate the plants and sometimes each other ...\n");
-	printf("They began to bread and evolve ...\n");
+	printf("Then they began to bread and evolve ...\n");
 	
 	/* initalize the keyboard */
 	init_kb();
@@ -146,7 +247,7 @@ int main(int argc, char *argv[])
 	sd = read_kb();
 	sd = '\0';
 	
-	/* clear the screen */
+	/* clear the screen ... ansi compliant term required */
 	printf("%c[2J", 033);
 
 	/* set pointers */
@@ -157,6 +258,7 @@ int main(int argc, char *argv[])
 	old = bugs;
 	hk = bugs;
 	
+	/* user display mode */
 	u1mode = 2;
 	u2mode = 3;
 		
@@ -166,7 +268,6 @@ int main(int argc, char *argv[])
 		/* first bug in loop better check out some stuff */
 		if (bugs == first)
 		{
-			/* show this frame */
 			switch(dm)
 			{
 				case 0: /* world display */
@@ -175,12 +276,13 @@ int main(int argc, char *argv[])
 					printf("\n");
 					printf("%c[K", 033);
 					printf("%s\t%c  Ag=%i  Fd=%i  Gn=%i  Sz=%i  At=%i  Df=%i  Fv=%i", sbis, sb->race, sb->age, sb->food, sb->gen, sb->size, sb->attack, sb->defend, sb->fov);
+					printf("\n");
 					break;
 
 				case 1: /* MIN */
 					stat(0);
 					break;
-
+	
 				case 2: /* AVG */
 					stat(1);
 					break;
@@ -192,13 +294,13 @@ int main(int argc, char *argv[])
 				case 4: /* USER */
 					stat(3);
 					break;
-
+	
 				default:
-					printf("oops .. bad display mode\n");
+					fprintf(stderr, "oops .. bad display mode\n");
 					dm = 0;
 					break;
 			}
-
+			
 			/* grow food? */
 			fg = ++fg % FOOD_GROW;
 
@@ -352,35 +454,35 @@ int main(int argc, char *argv[])
 					u2mode = ++u2mode % 7;
 					break;
 
-				case '1': // make sb = next
+				case '1': /* make sb = next */
 					sbis = "";
 					sb = sb->next;
 					break;
 
-				case '2': // make sb = high food
+				case '2': /* make sb = high food */
 					sbis = "hf";
 					sb = hf;
 					break;
 
-				case '3': // make sb = high gen
+				case '3': /* make sb = high gen */
 					sbis = "hg";
 					sb = hg;
 					break;
 
-				case '4': // make sb = oldest
+				case '4': /* make sb = oldest */
 					sbis = "old";
 					sb = old;
 					break;
 
-				case '5': // make sb = highest kills
+				case '5': /* make sb = highest kills */
 					sbis = "hk";
 					sb = hk;
 					break;
 
-				case 'g': // snap screen to sb
+				case 'g': /* snap screen to sb */
 				case 'G':
-					tmpr = (sb->ypos - (RROW / 2) + world_row) % world_row;
-					tmpc = (sb->xpos - (RCOL / 2) + world_col) % world_col;
+					tmpr = (sb->ypos - (rrow / 2) + world_row) % world_row;
+					tmpc = (sb->xpos - (rcol / 2) + world_col) % world_col;
 					break;
 
 				case 'p': /* pause */
@@ -398,7 +500,7 @@ int main(int argc, char *argv[])
 	}
 	
 	/* ooops ... */
-	printf("we should never exit this way\n");
+	fprintf(stderr, "we should never exit this way\n");
 	stop(EXIT_1);
 	/* and evan if we do, we never get here */
 	return(EXIT_2);
@@ -409,6 +511,6 @@ void stop(int ec)
 {
 	/* restore keyborad */
 	close_kb();
-	printf("\nThank plaese come again ...\n");
+	printf("\nThank you, plaese come again ...\n");
 	exit(ec);
 }
