@@ -1,8 +1,9 @@
 /*
- * Copyright James Morse Y2K+1
+ * Copyright James Morse Y2K +1, +2
  * This is GPLed software 
  * please read COPYING
  *
+ * next error to be 16 ...
  */
 
 #ifndef ERROR_H
@@ -12,12 +13,15 @@
 #define EXIT_OK	0	/* exit no error */
 #define EXIT_1	1	/* left main loop */
 #define EXIT_2	2	/* stop is busted? */
-#define CMDL_1	3	/* bad -s args */
+#define CMDL_1	3	/* bad -w args */
 #define CMDL_2	4	/* bad -r args */
 #define CMDL_3	5	/* bad -g args */
 #define GNU_L	6	/* GNU licnse */
 #define CMDL_U	7	/* unknowen args */
 #define BM_B6	8	/* bad malloc of world */
+#define NO_FORK 13      /* no fork for display */
+#define CMDL_4	14	/* bad -s args */
+#define CMDL_H	15	/* user asked for help */
 
 /* findbug.c */
 #define FB_F	9	/* things are messed up bad */
